@@ -32,8 +32,8 @@ class ColumnQualifier(object):
         stage will fail on its precondition if trying to transform with it a
         dataframe that is missing some values in the fitted qualifier.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import numpy as np; import pdpipe as pdp;
     >>> cq = pdp.cq.ColumnQualifier(lambda df: [
     ...    l for l, s in df.iteritems()
@@ -52,12 +52,12 @@ class ColumnQualifier(object):
         self._fittable = fittable
         self._subset = subset
 
-    def __call__(self, df):
+    def __call__(self, X):
         """Returns column labels of qualified columns from an input dataframe.
 
         Parameters
         ----------
-        df : pandas.DataFrame
+        X : pandas.DataFrame
             The input dataframe, from which columns are selected.
 
         Returns
@@ -66,16 +66,16 @@ class ColumnQualifier(object):
             A list of labels of the qualified columns for the input dataframe.
         """
         try:
-            return self.transform(df)
+            return self.transform(X)
         except UnfittedColumnQualifierError:
-            return self.fit_transform(df)
+            return self.fit_transform(X)
 
-    def fit_transform(self, df):
-        """Fits this qualifier and returns the labels of the qualifying columns.
+    def fit_transform(self, X):
+        """Fit this qualifier and return the labels of the qualifying columns.
 
         Parameters
         ----------
-        df : pandas.DataFrame
+        X : pandas.DataFrame
             The input dataframe, from which columns are selected.
 
         Returns
@@ -83,21 +83,21 @@ class ColumnQualifier(object):
         list of objects
             A list of labels of the qualified columns for the input dataframe.
         """
-        self._columns = self._cqfunc(df)
+        self._columns = self._cqfunc(X)
         return self._columns
 
-    def fit(self, df):
+    def fit(self, X):
         """Fits this qualifier on the input dataframe.
 
         Parameters
         ----------
-        df : pandas.DataFrame
+        X : pandas.DataFrame
             The input dataframe, from which columns are selected.
 
         """
-        self.fit_transform(df)
+        self.fit_transform(X)
 
-    def transform(self, df):
+    def transform(self, X):
         """Applies and returns the labels of the qualifying columns.
 
         If this ColumnQualifier is fittable, it will return the list of column
@@ -107,7 +107,7 @@ class ColumnQualifier(object):
 
         Parameters
         ----------
-        df : pandas.DataFrame
+        X : pandas.DataFrame
             The input dataframe, from which columns are selected.
 
         Returns
@@ -116,10 +116,10 @@ class ColumnQualifier(object):
             A list of labels of the qualified columns for the input dataframe.
         """
         if not self._fittable:
-            return self._cqfunc(df)
+            return self._cqfunc(X)
         try:
             if self._subset:
-                return [x for x in self._columns if x in df.columns]
+                return [x for x in self._columns if x in X.columns]
             return self._columns
         except AttributeError:
             raise UnfittedColumnQualifierError
@@ -143,10 +143,10 @@ class ColumnQualifier(object):
             self.first = first
             self.second = second
 
-        def __call__(self, df):
+        def __call__(self, X):
             return ColumnQualifier._x_inorderof_y(
-                x=set(self.first(df)).intersection(self.second(df)),
-                y=df.columns,
+                x=set(self.first(X)).intersection(self.second(X)),
+                y=X.columns,
             )
 
     def __and__(self, other):
@@ -170,10 +170,10 @@ class ColumnQualifier(object):
             self.first = first
             self.second = second
 
-        def __call__(self, df):
+        def __call__(self, X):
             return ColumnQualifier._x_inorderof_y(
-                x=set(self.first(df)).symmetric_difference(self.second(df)),
-                y=df.columns,
+                x=set(self.first(X)).symmetric_difference(self.second(X)),
+                y=X.columns,
             )
 
     def __xor__(self, other):
@@ -197,10 +197,10 @@ class ColumnQualifier(object):
             self.first = first
             self.second = second
 
-        def __call__(self, df):
+        def __call__(self, X):
             return ColumnQualifier._x_inorderof_y(
-                x=set(self.first(df)).union(self.second(df)),
-                y=df.columns,
+                x=set(self.first(X)).union(self.second(X)),
+                y=X.columns,
             )
 
     def __or__(self, other):
@@ -224,10 +224,10 @@ class ColumnQualifier(object):
             self.first = first
             self.second = second
 
-        def __call__(self, df):
+        def __call__(self, X):
             return ColumnQualifier._x_inorderof_y(
-                x=set(self.first(df)).difference(self.second(df)),
-                y=df.columns,
+                x=set(self.first(X)).difference(self.second(X)),
+                y=X.columns,
             )
 
     def __sub__(self, other):
@@ -250,10 +250,10 @@ class ColumnQualifier(object):
         def __init__(self, cq):
             self.cq = cq
 
-        def __call__(self, df):
+        def __call__(self, X):
             return ColumnQualifier._x_inorderof_y(
-                x=set(df.columns).difference(self.cq(df)),
-                y=df.columns,
+                x=set(X.columns).difference(self.cq(X)),
+                y=X.columns,
             )
 
     def __invert__(self):
@@ -293,8 +293,8 @@ class AllColumns(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp;
     >>> df = pd.DataFrame([[8,1],[5,2]], [1,2], ['a', 'b'])
     >>> cq = pdp.cq.AllColumns()
@@ -319,8 +319,8 @@ class AllColumns(ColumnQualifier):
 
     class _SelectAllColumns(object):
 
-        def __call__(self, df):
-            return list(df.columns)
+        def __call__(self, X):
+            return list(X.columns)
 
     def __init__(self, **kwargs):
         kwargs['func'] = AllColumns._SelectAllColumns()
@@ -348,8 +348,8 @@ class ByColumnCondition(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp;
     >>> df = pd.DataFrame(
     ...    [[1, 2, 'A'],[4, 1, 'C']], [1,2], ['age', 'count', 'grade'])
@@ -374,9 +374,9 @@ class ByColumnCondition(ColumnQualifier):
         def __init__(self, cond):
             self.cond = cond
 
-        def __call__(self, df):
+        def __call__(self, X):
             return list([
-                lbl for lbl, series in df.iteritems()
+                lbl for lbl, series in X.iteritems()
                 if self.cond(series)
             ])
 
@@ -400,8 +400,8 @@ class ByLabels(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp;
     >>> df = pd.DataFrame(
     ...    [[8,'a',5],[5,'b',7]], [1,2], ['num', 'chr', 'nur'])
@@ -421,9 +421,9 @@ class ByLabels(ColumnQualifier):
         def __init__(self, labels):
             self.labels = labels
 
-        def __call__(self, df):
+        def __call__(self, X):
             return [
-                lbl for lbl in df.columns
+                lbl for lbl in X.columns
                 if lbl in self.labels
             ]
 
@@ -457,8 +457,8 @@ def columns_to_qualifier(columns):
     qualifier : ColumnQualifier
         The equivalent ColumnQualifier object.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pdpipe as pdp;
     >>> pdp.cq.columns_to_qualifier('nu')
     <ColumnQualifier: By labels in nu>
@@ -474,7 +474,7 @@ def columns_to_qualifier(columns):
     return ByLabels(columns)
 
 
-class StartWith(ColumnQualifier):
+class StartsWith(ColumnQualifier):
     """Selectes all columns that start with the given string.
 
     Parameters
@@ -486,12 +486,12 @@ class StartWith(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp;
     >>> df = pd.DataFrame(
     ...    [[8,'a',5],[5,'b',7]], [1,2], ['num', 'chr', 'nur'])
-    >>> cq = pdp.cq.StartWith('nu')
+    >>> cq = pdp.cq.StartsWith('nu')
     >>> cq
     <ColumnQualifier: Columns starting with nu>
     >>> cq(df)
@@ -505,20 +505,20 @@ class StartWith(ColumnQualifier):
         except AttributeError:
             return False
 
-    class _StartWithFunc(object):
+    class _StartsWithFunc(object):
 
         def __init__(self, prefix):
             self.prefix = prefix
 
-        def __call__(self, df):
+        def __call__(self, X):
             return [
-                lbl for lbl in df.columns
-                if StartWith._safe_startwith(lbl, self.prefix)
+                lbl for lbl in X.columns
+                if StartsWith._safe_startwith(lbl, self.prefix)
             ]
 
     def __init__(self, prefix, **kwargs):
         self._prefix = prefix
-        cqfunc = StartWith._StartWithFunc(prefix)
+        cqfunc = StartsWith._StartsWithFunc(prefix)
         cqfunc.__doc__ = f"Columns that start with {self._prefix}"
         self.__doc__ = cqfunc.__doc__
         kwargs['func'] = cqfunc
@@ -543,8 +543,8 @@ class OfDtypes(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
     >>> df = pd.DataFrame(
     ...    [[8.2,'a',5],[5.1,'b',7]], [1,2], ['ph', 'grade', 'age'])
@@ -566,8 +566,8 @@ class OfDtypes(ColumnQualifier):
         def __init__(self, dtypes):
             self.dtypes = dtypes
 
-        def __call__(self, df):
-            return list(df.select_dtypes(include=self.dtypes).columns)
+        def __call__(self, X):
+            return list(X.select_dtypes(include=self.dtypes).columns)
 
     def __init__(self, dtypes, **kwargs):
         self._dtypes = dtypes
@@ -592,8 +592,8 @@ class OfNumericDtypes(OfDtypes):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
     >>> df = pd.DataFrame(
     ...    [[8.2,'a',5],[5.1,'b',7]], [1,2], ['ph', 'grade', 'age'])
@@ -622,8 +622,8 @@ class WithAtMostMissingValues(ColumnQualifier):
         ColumnQualifier. See the documentation of `ColumnQualifier` for
         details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
     >>> df = pd.DataFrame(
     ...    [[None, 1, 2],[None, None, 5]], [1,2], ['ph', 'grade', 'age'])
@@ -639,8 +639,8 @@ class WithAtMostMissingValues(ColumnQualifier):
         def __init__(self, n_missing):
             self._n_missing = n_missing
 
-        def __call__(self, df):
-            return list(df.columns[df.isna().sum() <= self._n_missing])
+        def __call__(self, X):
+            return list(X.columns[X.isna().sum() <= self._n_missing])
 
     def __init__(self, n_missing, **kwargs):
         self._n_missing = n_missing
@@ -666,8 +666,8 @@ class WithoutMissingValues(WithAtMostMissingValues):
         Accepts all keyword arguments of the constructor of ColumnQualifier.
         See the documentation of `ColumnQualifier` for details.
 
-    Example
-    -------
+    Examples
+    --------
     >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
     >>> df = pd.DataFrame(
     ...    [[None, 1, 2],[None, None, 5]], [1,2], ['ph', 'grade', 'age'])
@@ -684,3 +684,99 @@ class WithoutMissingValues(WithAtMostMissingValues):
 
     def __repr__(self):
         return "<ColumnQualifier: Without missing values>"
+
+
+class WithAtMostMissingValueRate(ColumnQualifier):
+    """Selectes all columns with no more than P% missing values.
+
+    Parameters
+    ----------
+    rate : float, between 0 and 1
+        The maximum rate of missing values with which columns can still
+        qualify.
+    **kwargs
+        Additionaly accepts all keyword arguments of the constructor of
+        ColumnQualifier. See the documentation of `ColumnQualifier` for
+        details.
+
+    Examples
+    --------
+    >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
+    >>> df = pd.DataFrame(
+    ...    [[None, 1, 2],[None, None, 5]], [1,2], ['ph', 'grade', 'age'])
+    >>> cq = pdp.cq.WithAtMostMissingValueRate(0.6)
+    >>> cq
+    <ColumnQualifier: With at most 0.6 missing value rate>
+    >>> cq(df)
+    ['grade', 'age']
+    """
+
+    class _AtMostRateFunc(object):
+
+        def __init__(self, rate):
+            self._rate = rate
+
+        def __call__(self, X):
+            return list(X.columns[(X.isna().sum() / len(X)) <= self._rate])
+
+    def __init__(self, rate, **kwargs):
+        self._rate = rate
+        cqfunc = WithAtMostMissingValueRate._AtMostRateFunc(rate)
+        cqfunc.__doc__ = (
+            f"Columns with at most {self._rate} missing value rate"
+        )
+        self.__doc__ = cqfunc.__doc__
+        kwargs['func'] = cqfunc
+        super().__init__(**kwargs)
+
+    def __repr__(self):
+        return f"<ColumnQualifier: " \
+               f"With at most {self._rate} missing value rate>"
+
+
+class WithAtLeastMissingValueRate(ColumnQualifier):
+    """Selectes all columns with no less than P% missing values.
+
+    Parameters
+    ----------
+    rate : float, between 0 and 1
+        The minimum rate of missing values with which columns can still
+        qualify.
+    **kwargs
+        Additionaly accepts all keyword arguments of the constructor of
+        ColumnQualifier. See the documentation of `ColumnQualifier` for
+        details.
+
+    Examples
+    --------
+    >>> import pandas as pd; import pdpipe as pdp; import numpy as np;
+    >>> df = pd.DataFrame(
+    ...    [[None, 1, 2],[None, None, 5]], [1,2], ['ph', 'grade', 'age'])
+    >>> cq = pdp.cq.WithAtLeastMissingValueRate(0.6)
+    >>> cq
+    <ColumnQualifier: With at least 0.6 missing value rate>
+    >>> cq(df)
+    ['ph']
+    """
+
+    class _AtLeastRateFunc(object):
+
+        def __init__(self, rate):
+            self._rate = rate
+
+        def __call__(self, X):
+            return list(X.columns[(X.isna().sum() / len(X)) >= self._rate])
+
+    def __init__(self, rate, **kwargs):
+        self._rate = rate
+        cqfunc = WithAtLeastMissingValueRate._AtLeastRateFunc(rate)
+        cqfunc.__doc__ = (
+            f"Columns with at least {self._rate} missing value rate"
+        )
+        self.__doc__ = cqfunc.__doc__
+        kwargs['func'] = cqfunc
+        super().__init__(**kwargs)
+
+    def __repr__(self):
+        return f"<ColumnQualifier: " \
+               f"With at least {self._rate} missing value rate>"
